@@ -1,5 +1,5 @@
-from ql_enums import *
-from ql_conventions import *
+from .ql_enums import *
+from .ql_conventions import *
 
 from pydantic import BaseModel, validator
 from typing import List, Optional
