@@ -1,9 +1,9 @@
 from typing import List
-from pymodels import *
+from .pymodels import *
 import QuantLib as ql
-from pym_ql_utils import *
-from ql_utils import *
-from ql_conventions import *
+from .pym_ql_utils import *
+from .ql_utils import *
+from .ql_conventions import *
 
 
 def curve_piecewise(value_date: str, 
